==> duckdb_0.2.2-1.tar.gz: duckdb/src/duckdb/amalgamation-6.cpp <==
#include "src/parser/transform/helpers/transform_groupby.cpp"

#include "src/parser/transform/helpers/transform_orderby.cpp"

#include "src/parser/transform/helpers/transform_typename.cpp"

#include "src/parser/transform/statement/transform_alter_table.cpp"

#include "src/parser/transform/statement/transform_call.cpp"

#include "src/parser/transform/statement/transform_copy.cpp"

#include "src/parser/transform/statement/transform_create_index.cpp"

#include "src/parser/transform/statement/transform_create_schema.cpp"

#include "src/parser/transform/statement/transform_create_sequence.cpp"

#include "src/parser/transform/statement/transform_create_table.cpp"

#include "src/parser/transform/statement/transform_create_table_as.cpp"

#include "src/parser/transform/statement/transform_create_view.cpp"

#include "src/parser/transform/statement/transform_delete.cpp"

#include "src/parser/transform/statement/transform_drop.cpp"

#include "src/parser/transform/statement/transform_explain.cpp"

#include "src/parser/transform/statement/transform_export.cpp"

#include "src/parser/transform/statement/transform_import.cpp"

#include "src/parser/transform/statement/transform_insert.cpp"

#include "src/parser/transform/statement/transform_pragma.cpp"

#include "src/parser/transform/statement/transform_prepare.cpp"

#include "src/parser/transform/statement/transform_rename.cpp"

#include "src/parser/transform/statement/transform_select.cpp"

#include "src/parser/transform/statement/transform_select_node.cpp"

#include "src/parser/transform/statement/transform_show.cpp"

#include "src/parser/transform/statement/transform_transaction.cpp"

#include "src/parser/transform/statement/transform_update.cpp"

#include "src/parser/transform/statement/transform_vacuum.cpp"

#include "src/parser/transform/tableref/transform_base_tableref.cpp"

#include "src/parser/transform/tableref/transform_from.cpp"

#include "src/parser/transform/tableref/transform_join.cpp"

#include "src/parser/transform/tableref/transform_subquery.cpp"

#include "src/parser/transform/tableref/transform_table_function.cpp"

#include "src/parser/transform/tableref/transform_tableref.cpp"

#include "src/parser/transformer.cpp"

#include "src/planner/bind_context.cpp"

#include "src/planner/binder.cpp"

#include "src/planner/binder/expression/bind_aggregate_expression.cpp"

#include "src/planner/binder/expression/bind_case_expression.cpp"

#include "src/planner/binder/expression/bind_cast_expression.cpp"

#include "src/planner/binder/expression/bind_collate_expression.cpp"

#include "src/planner/binder/expression/bind_columnref_expression.cpp"

#include "src/planner/binder/expression/bind_comparison_expression.cpp"

#include "src/planner/binder/expression/bind_conjunction_expression.cpp"

#include "src/planner/binder/expression/bind_constant_expression.cpp"

#include "src/planner/binder/expression/bind_function_expression.cpp"

#include "src/planner/binder/expression/bind_operator_expression.cpp"

#include "src/planner/binder/expression/bind_parameter_expression.cpp"

#include "src/planner/binder/expression/bind_subquery_expression.cpp"

#include "src/planner/binder/expression/bind_unnest_expression.cpp"

#include "src/planner/binder/expression/bind_window_expression.cpp"

#include "src/planner/binder/query_node/bind_recursive_cte_node.cpp"

#include "src/planner/binder/query_node/bind_select_node.cpp"

#include "src/planner/binder/query_node/bind_setop_node.cpp"

#include "src/planner/binder/query_node/plan_query_node.cpp"

#include "src/planner/binder/query_node/plan_recursive_cte_node.cpp"

#include "src/planner/binder/query_node/plan_select_node.cpp"

#include "src/planner/binder/query_node/plan_setop.cpp"

#include "src/planner/binder/query_node/plan_subquery.cpp"

#include "src/planner/binder/statement/bind_call.cpp"

#include "src/planner/binder/statement/bind_copy.cpp"

#include "src/planner/binder/statement/bind_create.cpp"

#include "src/planner/binder/statement/bind_create_table.cpp"

#include "src/planner/binder/statement/bind_delete.cpp"

#include "src/planner/binder/statement/bind_drop.cpp"

#include "src/planner/binder/statement/bind_execute.cpp"

#include "src/planner/binder/statement/bind_explain.cpp"

#include "src/planner/binder/statement/bind_export.cpp"

#include "src/planner/binder/statement/bind_insert.cpp"

#include "src/planner/binder/statement/bind_pragma.cpp"

#include "src/planner/binder/statement/bind_relation.cpp"

#include "src/planner/binder/statement/bind_select.cpp"

#include "src/planner/binder/statement/bind_simple.cpp"

#include "src/planner/binder/statement/bind_update.cpp"

#include "src/planner/binder/statement/bind_vacuum.cpp"

#include "src/planner/binder/tableref/bind_basetableref.cpp"

#include "src/planner/binder/tableref/bind_crossproductref.cpp"

#include "src/planner/binder/tableref/bind_emptytableref.cpp"

#include "src/planner/binder/tableref/bind_expressionlistref.cpp"

#include "src/planner/binder/tableref/bind_joinref.cpp"

==> duckdb_0.2.3.tar.gz: duckdb/src/duckdb/amalgamation-6.cpp <==
#include "src/parser/transform/helpers/nodetype_to_string.cpp"

#include "src/parser/transform/helpers/transform_alias.cpp"

#include "src/parser/transform/helpers/transform_cte.cpp"

#include "src/parser/transform/helpers/transform_groupby.cpp"

#include "src/parser/transform/helpers/transform_orderby.cpp"

#include "src/parser/transform/helpers/transform_typename.cpp"

#include "src/parser/transform/statement/transform_alter_table.cpp"

#include "src/parser/transform/statement/transform_call.cpp"

#include "src/parser/transform/statement/transform_copy.cpp"

#include "src/parser/transform/statement/transform_create_function.cpp"

#include "src/parser/transform/statement/transform_create_index.cpp"

#include "src/parser/transform/statement/transform_create_schema.cpp"

#include "src/parser/transform/statement/transform_create_sequence.cpp"

#include "src/parser/transform/statement/transform_create_table.cpp"

#include "src/parser/transform/statement/transform_create_table_as.cpp"

#include "src/parser/transform/statement/transform_create_view.cpp"

#include "src/parser/transform/statement/transform_delete.cpp"

#include "src/parser/transform/statement/transform_drop.cpp"

#include "src/parser/transform/statement/transform_explain.cpp"

#include "src/parser/transform/statement/transform_export.cpp"

#include "src/parser/transform/statement/transform_import.cpp"

#include "src/parser/transform/statement/transform_insert.cpp"

#include "src/parser/transform/statement/transform_pragma.cpp"

#include "src/parser/transform/statement/transform_prepare.cpp"

#include "src/parser/transform/statement/transform_rename.cpp"

#include "src/parser/transform/statement/transform_select.cpp"

#include "src/parser/transform/statement/transform_select_node.cpp"

#include "src/parser/transform/statement/transform_show.cpp"

#include "src/parser/transform/statement/transform_transaction.cpp"

#include "src/parser/transform/statement/transform_update.cpp"

#include "src/parser/transform/statement/transform_vacuum.cpp"

#include "src/parser/transform/tableref/transform_base_tableref.cpp"

#include "src/parser/transform/tableref/transform_from.cpp"

#include "src/parser/transform/tableref/transform_join.cpp"

#include "src/parser/transform/tableref/transform_subquery.cpp"

#include "src/parser/transform/tableref/transform_table_function.cpp"

#include "src/parser/transform/tableref/transform_tableref.cpp"

#include "src/parser/transformer.cpp"

#include "src/planner/bind_context.cpp"

#include "src/planner/binder.cpp"

#include "src/planner/binder/expression/bind_aggregate_expression.cpp"

#include "src/planner/binder/expression/bind_case_expression.cpp"

#include "src/planner/binder/expression/bind_cast_expression.cpp"

#include "src/planner/binder/expression/bind_collate_expression.cpp"

#include "src/planner/binder/expression/bind_columnref_expression.cpp"

#include "src/planner/binder/expression/bind_comparison_expression.cpp"

#include "src/planner/binder/expression/bind_conjunction_expression.cpp"

#include "src/planner/binder/expression/bind_constant_expression.cpp"

#include "src/planner/binder/expression/bind_function_expression.cpp"

#include "src/planner/binder/expression/bind_macro_expression.cpp"

#include "src/planner/binder/expression/bind_operator_expression.cpp"

#include "src/planner/binder/expression/bind_parameter_expression.cpp"

#include "src/planner/binder/expression/bind_subquery_expression.cpp"

#include "src/planner/binder/expression/bind_unnest_expression.cpp"

#include "src/planner/binder/expression/bind_window_expression.cpp"

#include "src/planner/binder/query_node/bind_recursive_cte_node.cpp"

#include "src/planner/binder/query_node/bind_select_node.cpp"

#include "src/planner/binder/query_node/bind_setop_node.cpp"

#include "src/planner/binder/query_node/plan_query_node.cpp"

#include "src/planner/binder/query_node/plan_recursive_cte_node.cpp"

#include "src/planner/binder/query_node/plan_select_node.cpp"

#include "src/planner/binder/query_node/plan_setop.cpp"

#include "src/planner/binder/query_node/plan_subquery.cpp"

#include "src/planner/binder/statement/bind_call.cpp"

#include "src/planner/binder/statement/bind_copy.cpp"

#include "src/planner/binder/statement/bind_create.cpp"

#include "src/planner/binder/statement/bind_create_table.cpp"

#include "src/planner/binder/statement/bind_delete.cpp"

#include "src/planner/binder/statement/bind_drop.cpp"

#include "src/planner/binder/statement/bind_execute.cpp"

#include "src/planner/binder/statement/bind_explain.cpp"

#include "src/planner/binder/statement/bind_export.cpp"

#include "src/planner/binder/statement/bind_insert.cpp"

#include "src/planner/binder/statement/bind_pragma.cpp"

#include "src/planner/binder/statement/bind_relation.cpp"

#include "src/planner/binder/statement/bind_select.cpp"

#include "src/planner/binder/statement/bind_simple.cpp"

#include "src/planner/binder/statement/bind_update.cpp"

#include "src/planner/binder/statement/bind_vacuum.cpp"

#include "src/planner/binder/tableref/bind_basetableref.cpp"

#include "src/planner/binder/tableref/bind_crossproductref.cpp"

#include "src/planner/binder/tableref/bind_emptytableref.cpp"

#include "src/planner/binder/tableref/bind_expressionlistref.cpp"

#include "src/planner/binder/tableref/bind_joinref.cpp"

#include "src/planner/binder/tableref/bind_named_parameters.cpp"

#include "src/planner/binder/tableref/bind_subqueryref.cpp"

#include "src/planner/binder/tableref/bind_table_function.cpp"
